==> immibis-microblocks-56.0.2.jar: src/mods/immibis/microblocks/coremod/CoreModOptions.java <==
package mods.immibis.microblocks.coremod;


import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;
import java.util.Properties;

import mods.immibis.microblocks.coremod.OptionsFile.BooleanOption;
import mods.immibis.microblocks.coremod.OptionsFile.ItemAndMetaListOption;
import mods.immibis.microblocks.coremod.OptionsFile.StringSetOption;
import mods.immibis.microblocks.coremod.OptionsFile.ItemListOption.ItemID;

import com.google.common.collect.ImmutableSet;

public class CoreModOptions {
	public static boolean autoDetectCuttableBlocks;
	public static List<ItemID> manualCuttableBlocks;
	public static boolean enableNEI;
	//public static boolean replaceVanillaBlocks;
	
	public static final ImmutableSet<String> DEFAULT_BLOCK_CLASSES = ImmutableSet.of(
		"buildcraft.transport.BlockGenericPipe",
		"ic2.core.block.wiring.BlockCable",
		"appeng.common.base.AppEngMultiBlock",
		"powercrystals.minefactoryreloaded.block.BlockRedNetCable",
		"micdoodle8.mods.galacticraft.core.blocks.GCCoreBlockOxygenPipe",
		"thermalexpansion.block.conduit.BlockConduit"
	);
	public static final ImmutableSet<String> DEFAULT_TILE_CLASSES = ImmutableSet.of(
		"buildcraft.transport.TileGenericPipe",
		"ic2.core.block.wiring.TileEntityCable",
		"appeng.me.tile.TileCable",
		"appeng.me.tile.TileDarkCable",
		"appeng.me.tile.TileInputCable",
		"appeng.me.tile.TileOutputCable",
		"appeng.me.tile.TileLevelEmitter",
		"appeng.me.tile.TileStorageBus",
		"appeng.me.tile.TileColorlessCable",
		"powercrystals.minefactoryreloaded.tile.rednet.TileEntityRedNetCable",
		"micdoodle8.mods.galacticraft.core.tile.GCCoreTileEntityOxygenPipe",
		"thermalexpansion.block.conduit.TileConduitEnergy",
		"thermalexpansion.block.conduit.TileConduitLiquid"
	);
	
	private static boolean loaded;
	private static File configFile;
	private static File configDir;
	
	private static OptionsFile of;
	public static boolean skipMicroblockTicks;
	
	private static void updateConfig() throws IOException {
		File oldConfigFile = new File(configDir, "immibis-coremod.cfg");
		if(oldConfigFile.exists()) {
			Properties props = new Properties();
			
			try {
				FileReader fr = new FileReader(oldConfigFile);
				try {
					props.load(fr);
				} finally {
					fr.close();
				}
			} catch(IOException ex) {
				throw new RuntimeException(ex);
			}
			
			StringSetOption blockClasses = new StringSetOption("blockClass");
			StringSetOption tileClasses = new StringSetOption("tileEntityClass");
			BooleanOption autoDetect = new BooleanOption("autoDetectCuttableBlocks");
			
			OptionsFile of = new OptionsFile();
			of.addOption(blockClasses);
			of.addOption(tileClasses);
			of.addOption(autoDetect);
			
			blockClasses.addValues(Arrays.asList(props.getProperty("microblockTransformer.blockClasses").split(";")));
			tileClasses.addValues(Arrays.asList(props.getProperty("microblockTransformer.tileEntityClasses").split(";")));
			autoDetect.set(props.getProperty("autoDetectCuttableBlocks", "false").equals("true"));
			
			of.write(configFile);
			
			oldConfigFile.delete();
		}
	}
	
	public static void load(File minecraftDir) {
		if(loaded)
			return;
		
		loaded = true;
		
		configDir = new File(minecraftDir, "config");
		if(!configDir.exists() && !configDir.mkdirs())
			throw new RuntimeException("Couldn't create directory: "+configDir);
		configFile = new File(configDir, "immibis-microblocks.cfg");
		
		try {
			updateConfig();
		} catch(IOException e) {
			throw new RuntimeException(e);
		}
		
		StringSetOption blockClasses = new StringSetOption("blockClass", DEFAULT_BLOCK_CLASSES);
		StringSetOption tileClasses = new StringSetOption("tileEntityClass", DEFAULT_TILE_CLASSES);
		BooleanOption autoDetect = new BooleanOption("autoDetectCuttableBlocks", false);
		ItemAndMetaListOption cuttableBlocks = new ItemAndMetaListOption("cuttableBlock");
		BooleanOption enableNEIOption = new BooleanOption("enableNEI", true);
		//BooleanOption skipMicroblockTicksOption = new BooleanOption("skipMicroblockTicks", true);
		//BooleanOption replaceVanillaBlocksOption = new BooleanOption("replaceVanillaBlocks", false);
		
		of = new OptionsFile();
		of.addOption(blockClasses);
		of.addOption(tileClasses);
		of.addOption(autoDetect);
		of.addOption(cuttableBlocks);
		of.addOption(enableNEIOption);
		//of.addOption(skipMicroblockTicksOption);
		//of.addOption(replaceVanillaBlocksOption);
		
		if(configFile.exists()) {
			try {
				of.read(configFile);
			} catch(IOException e) {
				throw new RuntimeException(e);
			}
		}
		
		manualCuttableBlocks = cuttableBlocks.get();
		autoDetectCuttableBlocks = autoDetect.get();
		enableNEI = enableNEIOption.get();
		//skipMicroblockTicks = skipMicroblockTicksOption.get();
		skipMicroblockTicks = true;
		//replaceVanillaBlocks = replaceVanillaBlocksOption.get();
		MicroblockSupporterTransformer.blockClasses.addAll(blockClasses.get());
		MicroblockSupporterTransformer.tileClasses.addAll(tileClasses.get());
		
		save();
	}
	
	public static void save() {
		of.<ItemAndMetaListOption>getOption("cuttableBlock").set(manualCuttableBlocks);
		of.<BooleanOption>getOption("autoDetectCuttableBlocks").set(autoDetectCuttableBlocks);
		if(OptionsFile.DEBUG)
			System.out.println("[Immibis's Microblocks DEBUG] Saving config file");
		try {
			of.write(configFile);
		} catch(IOException e) {
			throw new RuntimeException(e);
		}
	}
}

==> immibis-microblocks-57.3.2.jar: src/mods/immibis/microblocks/coremod/CoreModOptions.java <==
package mods.immibis.microblocks.coremod;


import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;
import java.util.Properties;

import mods.immibis.microblocks.coremod.OptionsFile.BooleanOption;
import mods.immibis.microblocks.coremod.OptionsFile.ItemAndMetaListOption;
import mods.immibis.microblocks.coremod.OptionsFile.StringSetOption;
import mods.immibis.microblocks.coremod.OptionsFile.ItemListOption.ItemID;

import com.google.common.collect.ImmutableSet;

public class CoreModOptions {
	public static boolean autoDetectCuttableBlocks;
	public static List<ItemID> manualCuttableBlocks;
	public static boolean enableNEI;
	//public static boolean replaceVanillaBlocks;
	
	public static final ImmutableSet<String> DEFAULT_BLOCK_CLASSES = ImmutableSet.of(
		"buildcraft.transport.BlockGenericPipe",
		"ic2.core.block.wiring.BlockCable",
		"appeng.common.base.AppEngMultiBlock",
		"powercrystals.minefactoryreloaded.block.BlockRedNetCable",
		"micdoodle8.mods.galacticraft.core.blocks.GCCoreBlockOxygenPipe",
		"thermalexpansion.block.conduit.BlockConduit"
		//"net.minecraft.block.BlockTorch"
	);
	public static final ImmutableSet<String> DEFAULT_TILE_CLASSES = ImmutableSet.of(
		"buildcraft.transport.TileGenericPipe",
		"ic2.core.block.wiring.TileEntityCable",
		"appeng.me.tile.TileCable",
		"appeng.me.tile.TileDarkCable",
		"appeng.me.tile.TileInputCable",
		"appeng.me.tile.TileOutputCable",
		"appeng.me.tile.TileLevelEmitter",
		"appeng.me.tile.TileStorageBus",
		"appeng.me.tile.TileColorlessCable",
		"powercrystals.minefactoryreloaded.tile.rednet.TileEntityRedNetCable",
		"micdoodle8.mods.galacticraft.core.tile.GCCoreTileEntityOxygenPipe",
		"thermalexpansion.block.conduit.energy.TileConduitEnergy",
		"thermalexpansion.block.conduit.fluid.TileConduitFluid",
		"thermalexpansion.block.conduit.item.TileConduitItem",
		"mods.immibis.microblocks.TileMicroblockContainerDefaultTE"
	);
	
	private static boolean loaded;
	private static File configFile;
	private static File configDir;
	
	private static OptionsFile of;
	public static boolean skipMicroblockTicks;
	
	private static void updateConfig() throws IOException {
		File oldConfigFile = new File(configDir, "immibis-coremod.cfg");
		if(oldConfigFile.exists()) {
			Properties props = new Properties();
			
			try {
				FileReader fr = new FileReader(oldConfigFile);
				try {
					props.load(fr);
				} finally {
					fr.close();
				}
			} catch(IOException ex) {
				throw new RuntimeException(ex);
			}
			
			StringSetOption blockClasses = new StringSetOption("blockClass");
			StringSetOption tileClasses = new StringSetOption("tileEntityClass");
			BooleanOption autoDetect = new BooleanOption("autoDetectCuttableBlocks");
			
			OptionsFile of = new OptionsFile();
			of.addOption(blockClasses);
			of.addOption(tileClasses);
			of.addOption(autoDetect);
			
			blockClasses.addValues(Arrays.asList(props.getProperty("microblockTransformer.blockClasses").split(";")));
			tileClasses.addValues(Arrays.asList(props.getProperty("microblockTransformer.tileEntityClasses").split(";")));
			autoDetect.set(props.getProperty("autoDetectCuttableBlocks", "false").equals("true"));
			
			of.write(configFile);
			
			oldConfigFile.delete();
		}
	}
	
	public static void load(File minecraftDir) {
		if(loaded)
			return;
		
		loaded = true;
		
		configDir = new File(minecraftDir, "config");
		if(!configDir.exists() && !configDir.mkdirs())
			throw new RuntimeException("Couldn't create directory: "+configDir);
		configFile = new File(configDir, "immibis-microblocks.cfg");
		
		try {
			updateConfig();
		} catch(IOException e) {
			throw new RuntimeException(e);
		}
		
		StringSetOption blockClasses = new StringSetOption("blockClass", DEFAULT_BLOCK_CLASSES);
		StringSetOption tileClasses = new StringSetOption("tileEntityClass", DEFAULT_TILE_CLASSES);
		BooleanOption autoDetect = new BooleanOption("autoDetectCuttableBlocks", false);
		ItemAndMetaListOption cuttableBlocks = new ItemAndMetaListOption("cuttableBlock");
		BooleanOption enableNEIOption = new BooleanOption("enableNEI", true);
		//BooleanOption skipMicroblockTicksOption = new BooleanOption("skipMicroblockTicks", true);
		//BooleanOption replaceVanillaBlocksOption = new BooleanOption("replaceVanillaBlocks", false);
		
		of = new OptionsFile();
		of.addOption(blockClasses);
		of.addOption(tileClasses);
		of.addOption(autoDetect);
		of.addOption(cuttableBlocks);
		of.addOption(enableNEIOption);
		//of.addOption(skipMicroblockTicksOption);
		//of.addOption(replaceVanillaBlocksOption);
		
		if(configFile.exists()) {
			try {
				of.read(configFile);
			} catch(IOException e) {
				throw new RuntimeException(e);
			}
		}
		
		manualCuttableBlocks = cuttableBlocks.get();
		autoDetectCuttableBlocks = autoDetect.get();
		enableNEI = enableNEIOption.get();
		//skipMicroblockTicks = skipMicroblockTicksOption.get();
		skipMicroblockTicks = true;
		//replaceVanillaBlocks = replaceVanillaBlocksOption.get();
		MicroblockSupporterTransformer.blockClasses.addAll(blockClasses.get());
		MicroblockSupporterTransformer.tileClasses.addAll(tileClasses.get());
		
		save();
	}
	
	public static void save() {
		of.<ItemAndMetaListOption>getOption("cuttableBlock").set(manualCuttableBlocks);
		of.<BooleanOption>getOption("autoDetectCuttableBlocks").set(autoDetectCuttableBlocks);
		if(OptionsFile.DEBUG)
			System.out.println("[Immibis's Microblocks DEBUG] Saving config file");
		try {
			of.write(configFile);
		} catch(IOException e) {
			throw new RuntimeException(e);
		}
	}
}
